# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .final_scores import FinalScores
from .helios_one_workflow_output import HeliosOneWorkflowOutput
from .initial_scores import InitialScores
from .workflow_error import WorkflowError


class TheiaOutput(UniversalBaseModel):
    errors: typing.Optional[typing.List[WorkflowError]] = None
    final_scores: typing.Optional[FinalScores] = None
    initial_scores: typing.Optional[InitialScores] = None
    merged_text: str
    original_text: str
    results: typing.List[HeliosOneWorkflowOutput]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .grammar_category import GrammarCategory


class GrammarChange(UniversalBaseModel):
    original: str = pydantic.Field()
    """
    The original text
    """

    modified: str = pydantic.Field()
    """
    The modified text
    """

    change_start_char_idx: typing.Optional[int] = pydantic.Field(default=None)
    """
    The start index of the change (calculated from context)
    """

    change_type: typing.Optional[typing.Literal["grammar"]] = None
    context_before: typing.Optional[str] = pydantic.Field(default=None)
    """
    Text that appears before the original text
    """

    context_after: typing.Optional[str] = pydantic.Field(default=None)
    """
    Text that appears after the original text
    """

    category: GrammarCategory

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import httpx
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .environment import AcrolinxEnvironment
from .style_checks.client import AsyncStyleChecksClient, StyleChecksClient
from .style_guides.client import AsyncStyleGuidesClient, StyleGuidesClient
from .style_rewrites.client import AsyncStyleRewritesClient, StyleRewritesClient
from .style_suggestions.client import AsyncStyleSuggestionsClient, StyleSuggestionsClient


class Acrolinx:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : AcrolinxEnvironment
        The environment to use for requests from the client. from .environment import AcrolinxEnvironment



        Defaults to AcrolinxEnvironment.PRODUCTION



    token : typing.Union[str, typing.Callable[[], str]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from acrolinx import Acrolinx

    client = Acrolinx(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: AcrolinxEnvironment = AcrolinxEnvironment.PRODUCTION,
        token: typing.Union[str, typing.Callable[[], str]],
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.style_guides = StyleGuidesClient(client_wrapper=self._client_wrapper)
        self.style_checks = StyleChecksClient(client_wrapper=self._client_wrapper)
        self.style_suggestions = StyleSuggestionsClient(client_wrapper=self._client_wrapper)
        self.style_rewrites = StyleRewritesClient(client_wrapper=self._client_wrapper)


class AsyncAcrolinx:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : AcrolinxEnvironment
        The environment to use for requests from the client. from .environment import AcrolinxEnvironment



        Defaults to AcrolinxEnvironment.PRODUCTION



    token : typing.Union[str, typing.Callable[[], str]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from acrolinx import AsyncAcrolinx

    client = AsyncAcrolinx(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: AcrolinxEnvironment = AcrolinxEnvironment.PRODUCTION,
        token: typing.Union[str, typing.Callable[[], str]],
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.style_guides = AsyncStyleGuidesClient(client_wrapper=self._client_wrapper)
        self.style_checks = AsyncStyleChecksClient(client_wrapper=self._client_wrapper)
        self.style_suggestions = AsyncStyleSuggestionsClient(client_wrapper=self._client_wrapper)
        self.style_rewrites = AsyncStyleRewritesClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: AcrolinxEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.rfc9457error import Rfc9457Error
from ...types.style_check_response import StyleCheckResponse
from ...types.workflow_status_response import WorkflowStatusResponse

StyleChecksGetStyleCheckResponse = typing.Union[WorkflowStatusResponse, StyleCheckResponse, Rfc9457Error]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .issue_category import IssueCategory
from .subcategory import Subcategory


class Issue(UniversalBaseModel):
    original: str = pydantic.Field()
    """
    The original text
    """

    char_index: int = pydantic.Field()
    """
    The start index of the change
    """

    subcategory: Subcategory = pydantic.Field()
    """
    The sub-category of the change
    """

    category: typing.Optional[IssueCategory] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

StyleGuides = typing.Union[
    typing.Literal["ap", "chicago", "microsoft", "proofpoint", "style_brand_importer"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .acrolinx_scorer_activity_output import AcrolinxScorerActivityOutput
from .analysis import Analysis
from .check_options import CheckOptions
from .clarity_score import ClarityScore
from .content_quality_feedback import ContentQualityFeedback
from .content_scorer_activity_output import ContentScorerActivityOutput
from .content_suggestions import ContentSuggestions
from .dialects import Dialects
from .error_detail import ErrorDetail
from .error_response import ErrorResponse
from .final_scores import FinalScores
from .grammar_activity_output import GrammarActivityOutput
from .grammar_category import GrammarCategory
from .grammar_change import GrammarChange
from .grammar_score import GrammarScore
from .helios_one_workflow_output import HeliosOneWorkflowOutput
from .initial_scores import InitialScores
from .issue import Issue
from .issue_category import IssueCategory
from .issue_scores import IssueScores
from .merging_activity_output import MergingActivityOutput
from .parameters import Parameters
from .parser_response import ParserResponse
from .quality_score import QualityScore
from .rewrite_response import RewriteResponse
from .rfc9457error import Rfc9457Error
from .score_output import ScoreOutput
from .sentence_length_activity_output import SentenceLengthActivityOutput
from .sentence_length_category import SentenceLengthCategory
from .sentence_length_change import SentenceLengthChange
from .sentence_structure_category import SentenceStructureCategory
from .sentence_structure_change import SentenceStructureChange
from .sentence_structure_output import SentenceStructureOutput
from .simple_vocab_category import SimpleVocabCategory
from .simple_vocab_change import SimpleVocabChange
from .simple_vocab_output import SimpleVocabOutput
from .style_check_response import StyleCheckResponse
from .style_guide import StyleGuide
from .style_guide_category import StyleGuideCategory
from .style_guide_change import StyleGuideChange
from .style_guide_output import StyleGuideOutput
from .style_guide_response import StyleGuideResponse
from .style_guide_score import StyleGuideScore
from .style_guide_status import StyleGuideStatus
from .style_guides import StyleGuides
from .subcategory import Subcategory
from .suggestion import Suggestion
from .suggestion_response import SuggestionResponse
from .term_replace_activity_output import TermReplaceActivityOutput
from .term_replace_category import TermReplaceCategory
from .term_replace_change import TermReplaceChange
from .terminology_score import TerminologyScore
from .theia_output import TheiaOutput
from .tone_category import ToneCategory
from .tone_change import ToneChange
from .tone_check_output import ToneCheckOutput
from .tone_score import ToneScore
from .tones import Tones
from .workflow_error import WorkflowError
from .workflow_response import WorkflowResponse
from .workflow_status import WorkflowStatus
from .workflow_status_response import WorkflowStatusResponse

__all__ = [
    "AcrolinxScorerActivityOutput",
    "Analysis",
    "CheckOptions",
    "ClarityScore",
    "ContentQualityFeedback",
    "ContentScorerActivityOutput",
    "ContentSuggestions",
    "Dialects",
    "ErrorDetail",
    "ErrorResponse",
    "FinalScores",
    "GrammarActivityOutput",
    "GrammarCategory",
    "GrammarChange",
    "GrammarScore",
    "HeliosOneWorkflowOutput",
    "InitialScores",
    "Issue",
    "IssueCategory",
    "IssueScores",
    "MergingActivityOutput",
    "Parameters",
    "ParserResponse",
    "QualityScore",
    "RewriteResponse",
    "Rfc9457Error",
    "ScoreOutput",
    "SentenceLengthActivityOutput",
    "SentenceLengthCategory",
    "SentenceLengthChange",
    "SentenceStructureCategory",
    "SentenceStructureChange",
    "SentenceStructureOutput",
    "SimpleVocabCategory",
    "SimpleVocabChange",
    "SimpleVocabOutput",
    "StyleCheckResponse",
    "StyleGuide",
    "StyleGuideCategory",
    "StyleGuideChange",
    "StyleGuideOutput",
    "StyleGuideResponse",
    "StyleGuideScore",
    "StyleGuideStatus",
    "StyleGuides",
    "Subcategory",
    "Suggestion",
    "SuggestionResponse",
    "TermReplaceActivityOutput",
    "TermReplaceCategory",
    "TermReplaceChange",
    "TerminologyScore",
    "TheiaOutput",
    "ToneCategory",
    "ToneChange",
    "ToneCheckOutput",
    "ToneScore",
    "Tones",
    "WorkflowError",
    "WorkflowResponse",
    "WorkflowStatus",
    "WorkflowStatusResponse",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .style_checks_get_style_check_response import StyleChecksGetStyleCheckResponse

__all__ = ["StyleChecksGetStyleCheckResponse"]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.internal_server_error import InternalServerError
from ..errors.not_found_error import NotFoundError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.dialects import Dialects
from ..types.error_response import ErrorResponse
from ..types.tones import Tones
from ..types.workflow_response import WorkflowResponse
from .types.style_rewrites_get_style_rewrite_response import StyleRewritesGetStyleRewriteResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawStyleRewritesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_style_rewrite(
        self,
        *,
        file_upload: core.File,
        dialect: Dialects,
        tone: Tones,
        style_guide: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[WorkflowResponse]:
        """
        Start a style and brand rewrite workflow. Returns a workflow ID to use for polling results.

        Parameters
        ----------
        file_upload : core.File
            See core.File for more documentation

        dialect : Dialects
            The language variant you'd like us to use for analysis. Choose from American English, British English, or other supported dialects.

        tone : Tones
            The tone variation you're aiming for. Options include formal, academic, casual, and other tone variations to match your content goals.

        style_guide : str
            The style guide to follow for your content. You can use a custom style guide ID or choose from built-in options like AP, Chicago, or Microsoft style guides.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[WorkflowResponse]
            Check run started successfully.
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/style/rewrites",
            method="POST",
            data={
                "dialect": dialect,
                "tone": tone,
                "style_guide": style_guide,
            },
            files={
                "file_upload": file_upload,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WorkflowResponse,
                    parse_obj_as(
                        type_=WorkflowResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ErrorResponse,
                        parse_obj_as(
                            type_=ErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_style_rewrite(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[StyleRewritesGetStyleRewriteResponse]:
        """
        Retrieve the results of a rewrite workflow. Returns `running` or `complete` status.

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[StyleRewritesGetStyleRewriteResponse]
            The rewrite run results.
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/style/rewrites/{jsonable_encoder(workflow_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StyleRewritesGetStyleRewriteResponse,
                    parse_obj_as(
                        type_=StyleRewritesGetStyleRewriteResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ErrorResponse,
                        parse_obj_as(
                            type_=ErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawStyleRewritesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_style_rewrite(
        self,
        *,
        file_upload: core.File,
        dialect: Dialects,
        tone: Tones,
        style_guide: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[WorkflowResponse]:
        """
        Start a style and brand rewrite workflow. Returns a workflow ID to use for polling results.

        Parameters
        ----------
        file_upload : core.File
            See core.File for more documentation

        dialect : Dialects
            The language variant you'd like us to use for analysis. Choose from American English, British English, or other supported dialects.

        tone : Tones
            The tone variation you're aiming for. Options include formal, academic, casual, and other tone variations to match your content goals.

        style_guide : str
            The style guide to follow for your content. You can use a custom style guide ID or choose from built-in options like AP, Chicago, or Microsoft style guides.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[WorkflowResponse]
            Check run started successfully.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/style/rewrites",
            method="POST",
            data={
                "dialect": dialect,
                "tone": tone,
                "style_guide": style_guide,
            },
            files={
                "file_upload": file_upload,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WorkflowResponse,
                    parse_obj_as(
                        type_=WorkflowResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ErrorResponse,
                        parse_obj_as(
                            type_=ErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_style_rewrite(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[StyleRewritesGetStyleRewriteResponse]:
        """
        Retrieve the results of a rewrite workflow. Returns `running` or `complete` status.

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[StyleRewritesGetStyleRewriteResponse]
            The rewrite run results.
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/style/rewrites/{jsonable_encoder(workflow_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StyleRewritesGetStyleRewriteResponse,
                    parse_obj_as(
                        type_=StyleRewritesGetStyleRewriteResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ErrorResponse,
                        parse_obj_as(
                            type_=ErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

StyleGuideCategory = typing.Union[
    typing.Literal[
        "punctuation",
        "capitalization",
        "spelling_and_grammar",
        "numbers_dates_times",
        "inclusive_language",
        "tone",
        "specific_conventions",
        "clarity_and_readability",
        "other",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.rfc9457error import Rfc9457Error
from ...types.style_check_response import StyleCheckResponse
from ...types.suggestion_response import SuggestionResponse
from ...types.workflow_status_response import WorkflowStatusResponse

StyleSuggestionsGetStyleSuggestionResponse = typing.Union[
    SuggestionResponse, WorkflowStatusResponse, StyleCheckResponse, Rfc9457Error
]



# This file was auto-generated by Fern from our API Definition.

import typing

IssueCategory = typing.Union[
    typing.Literal[
        "grammar", "sentence_length", "sentence_structure", "simple_vocab", "style_guide", "terminology", "tone"
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .dialects import Dialects
from .style_guide import StyleGuide
from .tones import Tones


class Parameters(UniversalBaseModel):
    dialect: typing.Optional[Dialects] = pydantic.Field(default=None)
    """
    The dialect used for the activity
    """

    tone: typing.Optional[Tones] = pydantic.Field(default=None)
    """
    The tone used for the activity
    """

    style_guide: typing.Optional[StyleGuide] = pydantic.Field(default=None)
    """
    The style guide used for the activity
    """

    max_words: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum number of words allowed for the activity
    """

    replace_terms: typing.Optional[str] = pydantic.Field(default=None)
    """
    Formatted string of terms to replace for the activity
    """

    do_not_flag_terms: typing.Optional[str] = pydantic.Field(default=None)
    """
    Formatted string of terms to not flag for the activity
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

ContentSuggestions = typing.Union[
    typing.Literal[
        "Use shorter sentences and simpler words to improve readability.",
        "Your text may be too complex. Consider simplifying vocabulary and sentence structure.",
        "Your sentences are quite long. Consider breaking them into shorter ones.",
        "Your sentences are very short. Consider combining some for better flow.",
        "Your vocabulary diversity is low. Try using a wider range of words.",
        "Your text is well-balanced. Consider proofreading for minor improvements.",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.dialects import Dialects
from ..types.tones import Tones
from ..types.workflow_response import WorkflowResponse
from .raw_client import AsyncRawStyleRewritesClient, RawStyleRewritesClient
from .types.style_rewrites_get_style_rewrite_response import StyleRewritesGetStyleRewriteResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class StyleRewritesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawStyleRewritesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawStyleRewritesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawStyleRewritesClient
        """
        return self._raw_client

    def create_style_rewrite(
        self,
        *,
        file_upload: core.File,
        dialect: Dialects,
        tone: Tones,
        style_guide: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WorkflowResponse:
        """
        Start a style and brand rewrite workflow. Returns a workflow ID to use for polling results.

        Parameters
        ----------
        file_upload : core.File
            See core.File for more documentation

        dialect : Dialects
            The language variant you'd like us to use for analysis. Choose from American English, British English, or other supported dialects.

        tone : Tones
            The tone variation you're aiming for. Options include formal, academic, casual, and other tone variations to match your content goals.

        style_guide : str
            The style guide to follow for your content. You can use a custom style guide ID or choose from built-in options like AP, Chicago, or Microsoft style guides.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkflowResponse
            Check run started successfully.

        Examples
        --------
        from acrolinx import Acrolinx

        client = Acrolinx(
            token="YOUR_TOKEN",
        )
        client.style_rewrites.create_style_rewrite(
            dialect="american_english",
            tone="academic",
            style_guide="style_guide",
        )
        """
        _response = self._raw_client.create_style_rewrite(
            file_upload=file_upload,
            dialect=dialect,
            tone=tone,
            style_guide=style_guide,
            request_options=request_options,
        )
        return _response.data

    def get_style_rewrite(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> StyleRewritesGetStyleRewriteResponse:
        """
        Retrieve the results of a rewrite workflow. Returns `running` or `complete` status.

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StyleRewritesGetStyleRewriteResponse
            The rewrite run results.

        Examples
        --------
        from acrolinx import Acrolinx

        client = Acrolinx(
            token="YOUR_TOKEN",
        )
        client.style_rewrites.get_style_rewrite(
            workflow_id="workflow_id",
        )
        """
        _response = self._raw_client.get_style_rewrite(workflow_id, request_options=request_options)
        return _response.data


class AsyncStyleRewritesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawStyleRewritesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawStyleRewritesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawStyleRewritesClient
        """
        return self._raw_client

    async def create_style_rewrite(
        self,
        *,
        file_upload: core.File,
        dialect: Dialects,
        tone: Tones,
        style_guide: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WorkflowResponse:
        """
        Start a style and brand rewrite workflow. Returns a workflow ID to use for polling results.

        Parameters
        ----------
        file_upload : core.File
            See core.File for more documentation

        dialect : Dialects
            The language variant you'd like us to use for analysis. Choose from American English, British English, or other supported dialects.

        tone : Tones
            The tone variation you're aiming for. Options include formal, academic, casual, and other tone variations to match your content goals.

        style_guide : str
            The style guide to follow for your content. You can use a custom style guide ID or choose from built-in options like AP, Chicago, or Microsoft style guides.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkflowResponse
            Check run started successfully.

        Examples
        --------
        import asyncio

        from acrolinx import AsyncAcrolinx

        client = AsyncAcrolinx(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.style_rewrites.create_style_rewrite(
                dialect="american_english",
                tone="academic",
                style_guide="style_guide",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_style_rewrite(
            file_upload=file_upload,
            dialect=dialect,
            tone=tone,
            style_guide=style_guide,
            request_options=request_options,
        )
        return _response.data

    async def get_style_rewrite(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> StyleRewritesGetStyleRewriteResponse:
        """
        Retrieve the results of a rewrite workflow. Returns `running` or `complete` status.

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StyleRewritesGetStyleRewriteResponse
            The rewrite run results.

        Examples
        --------
        import asyncio

        from acrolinx import AsyncAcrolinx

        client = AsyncAcrolinx(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.style_rewrites.get_style_rewrite(
                workflow_id="workflow_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_style_rewrite(workflow_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

ContentQualityFeedback = typing.Union[
    typing.Literal[
        "Excellent content quality! Your text is clear, readable, and well-structured.",
        "Good content quality. Your text is readable but has room for improvement.",
        "Moderate content quality. Consider revising for better readability.",
        "Low content quality. The text needs significant revision for better readability.",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .check_options import CheckOptions
from .score_output import ScoreOutput
from .style_guide_status import StyleGuideStatus
from .suggestion import Suggestion


class RewriteResponse(UniversalBaseModel):
    status: StyleGuideStatus
    scores: typing.Optional[ScoreOutput] = None
    issues: typing.List[Suggestion]
    check_options: CheckOptions
    rewrite: typing.Optional[str] = None
    rewrite_scores: typing.Optional[ScoreOutput] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

Tones = typing.Union[
    typing.Literal["academic", "business", "casual", "conversational", "formal", "gen-z", "informal", "technical"],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class Analysis(UniversalBaseModel):
    clarity_score: typing.Optional[float] = None
    word_count: typing.Optional[int] = None
    sentence_count: typing.Optional[int] = None
    avg_word_length: typing.Optional[float] = None
    avg_sentence_length: typing.Optional[float] = None
    flesch_reading_ease: typing.Optional[float] = None
    flesch_kincaid_grade: typing.Optional[float] = None
    lexical_diversity: typing.Optional[float] = None
    vocabulary_complexity: typing.Optional[float] = None
    sentence_complexity: typing.Optional[float] = None
    tone_score: typing.Optional[float] = None
    informality_score: typing.Optional[float] = None
    liveliness_score: typing.Optional[float] = None
    target_informality: typing.Optional[float] = None
    target_liveliness: typing.Optional[float] = None
    informality_tolerance: typing.Optional[float] = None
    liveliness_tolerance: typing.Optional[float] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .final_scores import FinalScores
from .grammar_activity_output import GrammarActivityOutput
from .initial_scores import InitialScores
from .merging_activity_output import MergingActivityOutput
from .parameters import Parameters
from .parser_response import ParserResponse
from .sentence_length_activity_output import SentenceLengthActivityOutput
from .sentence_structure_output import SentenceStructureOutput
from .simple_vocab_output import SimpleVocabOutput
from .style_guide_output import StyleGuideOutput
from .term_replace_activity_output import TermReplaceActivityOutput
from .tone_check_output import ToneCheckOutput
from .workflow_error import WorkflowError


class HeliosOneWorkflowOutput(UniversalBaseModel):
    created_at: str = pydantic.Field()
    """
    The date and time the workflow was created
    """

    errors: typing.Optional[typing.List[WorkflowError]] = pydantic.Field(default=None)
    """
    The errors that occurred during the workflow
    """

    initial_scores: typing.Optional[InitialScores] = pydantic.Field(default=None)
    """
    The initial scores of the workflow
    """

    final_scores: typing.Optional[FinalScores] = pydantic.Field(default=None)
    """
    The final scores of the workflow
    """

    input_file: str = pydantic.Field()
    """
    The path to the input file
    """

    parameters: typing.Optional[Parameters] = pydantic.Field(default=None)
    """
    The parameters used to run the workflow
    """

    run_id: str = pydantic.Field()
    """
    The Temporal workflow run ID
    """

    workflow_id: str = pydantic.Field()
    """
    The Temporal workflow ID
    """

    grammar_result: typing.Optional[GrammarActivityOutput] = pydantic.Field(default=None)
    """
    The result of the grammar activity
    """

    merging_result: typing.Optional[MergingActivityOutput] = pydantic.Field(default=None)
    """
    The result of the merging activity
    """

    parser_result: typing.Optional[ParserResponse] = pydantic.Field(default=None)
    """
    The result of the parser activity
    """

    sentence_length_result: typing.Optional[SentenceLengthActivityOutput] = pydantic.Field(default=None)
    """
    The result of the sentence length activity
    """

    sentence_structure_result: typing.Optional[SentenceStructureOutput] = pydantic.Field(default=None)
    """
    The result of the sentence structure activity
    """

    simple_vocabulary_result: typing.Optional[SimpleVocabOutput] = pydantic.Field(default=None)
    """
    The result of the simple vocabulary activity
    """

    tone_result: typing.Optional[ToneCheckOutput] = pydantic.Field(default=None)
    """
    The result of the tone activity
    """

    style_guide_result: typing.Optional[StyleGuideOutput] = pydantic.Field(default=None)
    """
    The result of the style guide activity
    """

    term_replace_result: typing.Optional[TermReplaceActivityOutput] = pydantic.Field(default=None)
    """
    The result of the terminology activity
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .acrolinx_scorer_activity_output import AcrolinxScorerActivityOutput
from .content_scorer_activity_output import ContentScorerActivityOutput
from .issue_scores import IssueScores


class InitialScores(UniversalBaseModel):
    acrolinx_score: typing.Optional[AcrolinxScorerActivityOutput] = None
    content_score: typing.Optional[ContentScorerActivityOutput] = None
    issue_score: typing.Optional[IssueScores] = None
    quality_score: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .dialects import Dialects
from .style_guide import StyleGuide
from .tones import Tones


class CheckOptions(UniversalBaseModel):
    style_guide: typing.Optional[StyleGuide] = None
    dialect: typing.Optional[Dialects] = None
    tone: typing.Optional[Tones] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .grammar_category import GrammarCategory
from .sentence_length_category import SentenceLengthCategory
from .sentence_structure_category import SentenceStructureCategory
from .simple_vocab_category import SimpleVocabCategory
from .style_guide_category import StyleGuideCategory
from .term_replace_category import TermReplaceCategory
from .tone_category import ToneCategory

Subcategory = typing.Union[
    GrammarCategory,
    SimpleVocabCategory,
    SentenceStructureCategory,
    SentenceLengthCategory,
    ToneCategory,
    StyleGuideCategory,
    TermReplaceCategory,
]



# This file was auto-generated by Fern from our API Definition.

import typing

Dialects = typing.Union[
    typing.Literal["american_english", "australian_english", "british_oxford", "canadian_english", "indian_english"],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.style_guide_response import StyleGuideResponse
from .raw_client import AsyncRawStyleGuidesClient, RawStyleGuidesClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class StyleGuidesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawStyleGuidesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawStyleGuidesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawStyleGuidesClient
        """
        return self._raw_client

    def list_style_guides(
        self,
        *,
        offset: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[StyleGuideResponse]:
        """
        Retrieve all style guides associated with your organization.

        Parameters
        ----------
        offset : typing.Optional[int]

        limit : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[StyleGuideResponse]
            Successful Response

        Examples
        --------
        from acrolinx import Acrolinx

        client = Acrolinx(
            token="YOUR_TOKEN",
        )
        client.style_guides.list_style_guides()
        """
        _response = self._raw_client.list_style_guides(offset=offset, limit=limit, request_options=request_options)
        return _response.data

    def create_style_guide(
        self,
        *,
        file_upload: core.File,
        name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> StyleGuideResponse:
        """
        Create a new style guide that can be used in checks, suggestions, and rewrites.

        Parameters
        ----------
        file_upload : core.File
            See core.File for more documentation

        name : typing.Optional[str]
            A friendly name for your style guide to help you identify it later. If left empty, we'll generate one for you.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StyleGuideResponse
            The style guide was created successfully and is being processed.

        Examples
        --------
        from acrolinx import Acrolinx

        client = Acrolinx(
            token="YOUR_TOKEN",
        )
        client.style_guides.create_style_guide()
        """
        _response = self._raw_client.create_style_guide(
            file_upload=file_upload, name=name, request_options=request_options
        )
        return _response.data

    def get_style_guide_by_id(
        self, style_guide_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> StyleGuideResponse:
        """
        Retrieve a specific style guide by ID, including its metadata such as `name` and `status`.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StyleGuideResponse
            Successful Response

        Examples
        --------
        from acrolinx import Acrolinx

        client = Acrolinx(
            token="YOUR_TOKEN",
        )
        client.style_guides.get_style_guide_by_id(
            style_guide_id="style_guide_id",
        )
        """
        _response = self._raw_client.get_style_guide_by_id(style_guide_id, request_options=request_options)
        return _response.data

    def delete_style_guide(
        self, style_guide_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete a style guide by ID.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from acrolinx import Acrolinx

        client = Acrolinx(
            token="YOUR_TOKEN",
        )
        client.style_guides.delete_style_guide(
            style_guide_id="style_guide_id",
        )
        """
        _response = self._raw_client.delete_style_guide(style_guide_id, request_options=request_options)
        return _response.data

    def update_style_guide(
        self,
        style_guide_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> StyleGuideResponse:
        """
        Update the name of an existing style guide.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        name : typing.Optional[str]
            The name of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StyleGuideResponse
            Successful Response

        Examples
        --------
        from acrolinx import Acrolinx

        client = Acrolinx(
            token="YOUR_TOKEN",
        )
        client.style_guides.update_style_guide(
            style_guide_id="style_guide_id",
        )
        """
        _response = self._raw_client.update_style_guide(style_guide_id, name=name, request_options=request_options)
        return _response.data


class AsyncStyleGuidesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawStyleGuidesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawStyleGuidesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawStyleGuidesClient
        """
        return self._raw_client

    async def list_style_guides(
        self,
        *,
        offset: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[StyleGuideResponse]:
        """
        Retrieve all style guides associated with your organization.

        Parameters
        ----------
        offset : typing.Optional[int]

        limit : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[StyleGuideResponse]
            Successful Response

        Examples
        --------
        import asyncio

        from acrolinx import AsyncAcrolinx

        client = AsyncAcrolinx(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.style_guides.list_style_guides()


        asyncio.run(main())
        """
        _response = await self._raw_client.list_style_guides(
            offset=offset, limit=limit, request_options=request_options
        )
        return _response.data

    async def create_style_guide(
        self,
        *,
        file_upload: core.File,
        name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> StyleGuideResponse:
        """
        Create a new style guide that can be used in checks, suggestions, and rewrites.

        Parameters
        ----------
        file_upload : core.File
            See core.File for more documentation

        name : typing.Optional[str]
            A friendly name for your style guide to help you identify it later. If left empty, we'll generate one for you.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StyleGuideResponse
            The style guide was created successfully and is being processed.

        Examples
        --------
        import asyncio

        from acrolinx import AsyncAcrolinx

        client = AsyncAcrolinx(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.style_guides.create_style_guide()


        asyncio.run(main())
        """
        _response = await self._raw_client.create_style_guide(
            file_upload=file_upload, name=name, request_options=request_options
        )
        return _response.data

    async def get_style_guide_by_id(
        self, style_guide_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> StyleGuideResponse:
        """
        Retrieve a specific style guide by ID, including its metadata such as `name` and `status`.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StyleGuideResponse
            Successful Response

        Examples
        --------
        import asyncio

        from acrolinx import AsyncAcrolinx

        client = AsyncAcrolinx(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.style_guides.get_style_guide_by_id(
                style_guide_id="style_guide_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_style_guide_by_id(style_guide_id, request_options=request_options)
        return _response.data

    async def delete_style_guide(
        self, style_guide_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete a style guide by ID.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from acrolinx import AsyncAcrolinx

        client = AsyncAcrolinx(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.style_guides.delete_style_guide(
                style_guide_id="style_guide_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_style_guide(style_guide_id, request_options=request_options)
        return _response.data

    async def update_style_guide(
        self,
        style_guide_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> StyleGuideResponse:
        """
        Update the name of an existing style guide.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        name : typing.Optional[str]
            The name of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StyleGuideResponse
            Successful Response

        Examples
        --------
        import asyncio

        from acrolinx import AsyncAcrolinx

        client = AsyncAcrolinx(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.style_guides.update_style_guide(
                style_guide_id="style_guide_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_style_guide(
            style_guide_id, name=name, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .clarity_score import ClarityScore
from .grammar_score import GrammarScore
from .quality_score import QualityScore
from .style_guide_score import StyleGuideScore
from .terminology_score import TerminologyScore
from .tone_score import ToneScore


class ScoreOutput(UniversalBaseModel):
    quality: QualityScore
    clarity: ClarityScore
    grammar: GrammarScore
    style_guide: StyleGuideScore
    tone: ToneScore
    terminology: TerminologyScore

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

SentenceStructureCategory = typing.Union[
    typing.Literal[
        "complex_verbs", "hidden_verbs", "insertion", "modal_verbs", "passive", "phrasal_verbs", "subjunctive", "other"
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

GrammarCategory = typing.Union[
    typing.Literal["sva_pronoun", "punct_cap", "spelling", "syntax", "verbs", "word_usage", "other"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.internal_server_error import InternalServerError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.error_response import ErrorResponse
from ..types.style_guide_response import StyleGuideResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawStyleGuidesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list_style_guides(
        self,
        *,
        offset: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.List[StyleGuideResponse]]:
        """
        Retrieve all style guides associated with your organization.

        Parameters
        ----------
        offset : typing.Optional[int]

        limit : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.List[StyleGuideResponse]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/style-guides",
            method="GET",
            params={
                "offset": offset,
                "limit": limit,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[StyleGuideResponse],
                    parse_obj_as(
                        type_=typing.List[StyleGuideResponse],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create_style_guide(
        self,
        *,
        file_upload: core.File,
        name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[StyleGuideResponse]:
        """
        Create a new style guide that can be used in checks, suggestions, and rewrites.

        Parameters
        ----------
        file_upload : core.File
            See core.File for more documentation

        name : typing.Optional[str]
            A friendly name for your style guide to help you identify it later. If left empty, we'll generate one for you.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[StyleGuideResponse]
            The style guide was created successfully and is being processed.
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/style-guides",
            method="POST",
            data={
                "name": name,
            },
            files={
                "file_upload": file_upload,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StyleGuideResponse,
                    parse_obj_as(
                        type_=StyleGuideResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ErrorResponse,
                        parse_obj_as(
                            type_=ErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_style_guide_by_id(
        self, style_guide_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[StyleGuideResponse]:
        """
        Retrieve a specific style guide by ID, including its metadata such as `name` and `status`.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[StyleGuideResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/style-guides/{jsonable_encoder(style_guide_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StyleGuideResponse,
                    parse_obj_as(
                        type_=StyleGuideResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_style_guide(
        self, style_guide_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[None]:
        """
        Delete a style guide by ID.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/style-guides/{jsonable_encoder(style_guide_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update_style_guide(
        self,
        style_guide_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[StyleGuideResponse]:
        """
        Update the name of an existing style guide.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        name : typing.Optional[str]
            The name of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[StyleGuideResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/style-guides/{jsonable_encoder(style_guide_id)}",
            method="PATCH",
            json={
                "name": name,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StyleGuideResponse,
                    parse_obj_as(
                        type_=StyleGuideResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawStyleGuidesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list_style_guides(
        self,
        *,
        offset: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.List[StyleGuideResponse]]:
        """
        Retrieve all style guides associated with your organization.

        Parameters
        ----------
        offset : typing.Optional[int]

        limit : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.List[StyleGuideResponse]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/style-guides",
            method="GET",
            params={
                "offset": offset,
                "limit": limit,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[StyleGuideResponse],
                    parse_obj_as(
                        type_=typing.List[StyleGuideResponse],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create_style_guide(
        self,
        *,
        file_upload: core.File,
        name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[StyleGuideResponse]:
        """
        Create a new style guide that can be used in checks, suggestions, and rewrites.

        Parameters
        ----------
        file_upload : core.File
            See core.File for more documentation

        name : typing.Optional[str]
            A friendly name for your style guide to help you identify it later. If left empty, we'll generate one for you.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[StyleGuideResponse]
            The style guide was created successfully and is being processed.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/style-guides",
            method="POST",
            data={
                "name": name,
            },
            files={
                "file_upload": file_upload,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StyleGuideResponse,
                    parse_obj_as(
                        type_=StyleGuideResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ErrorResponse,
                        parse_obj_as(
                            type_=ErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_style_guide_by_id(
        self, style_guide_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[StyleGuideResponse]:
        """
        Retrieve a specific style guide by ID, including its metadata such as `name` and `status`.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[StyleGuideResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/style-guides/{jsonable_encoder(style_guide_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StyleGuideResponse,
                    parse_obj_as(
                        type_=StyleGuideResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_style_guide(
        self, style_guide_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[None]:
        """
        Delete a style guide by ID.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/style-guides/{jsonable_encoder(style_guide_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update_style_guide(
        self,
        style_guide_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[StyleGuideResponse]:
        """
        Update the name of an existing style guide.

        Parameters
        ----------
        style_guide_id : str
            The ID of the style guide.

        name : typing.Optional[str]
            The name of the style guide.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[StyleGuideResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/style-guides/{jsonable_encoder(style_guide_id)}",
            method="PATCH",
            json={
                "name": name,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StyleGuideResponse,
                    parse_obj_as(
                        type_=StyleGuideResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .style_rewrites_get_style_rewrite_response import StyleRewritesGetStyleRewriteResponse

__all__ = ["StyleRewritesGetStyleRewriteResponse"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .style_suggestions_get_style_suggestion_response import StyleSuggestionsGetStyleSuggestionResponse

__all__ = ["StyleSuggestionsGetStyleSuggestionResponse"]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .style_guide_status import StyleGuideStatus


class StyleGuideResponse(UniversalBaseModel):
    id: str
    name: str = pydantic.Field()
    """
    The name of the style guide.
    """

    created_at: dt.datetime = pydantic.Field()
    """
    The UTC date and time the style guide was created.
    """

    created_by: str = pydantic.Field()
    """
    The user who created the style guide.
    """

    status: StyleGuideStatus = pydantic.Field()
    """
    The status of the submitted style guide.
    """

    updated_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The UTC datetime that the style guide was last updated. If null, the style guide has never been updated.
    """

    updated_by: typing.Optional[str] = pydantic.Field(default=None)
    """
    The user who last updated the style guide. If null, the style guide has never been updated.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

ToneCategory = typing.Union[
    typing.Literal["word_choice", "syntax", "punctuation", "discourse_features", "implicit_style", "other"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    AcrolinxScorerActivityOutput,
    Analysis,
    CheckOptions,
    ClarityScore,
    ContentQualityFeedback,
    ContentScorerActivityOutput,
    ContentSuggestions,
    Dialects,
    ErrorDetail,
    ErrorResponse,
    FinalScores,
    GrammarActivityOutput,
    GrammarCategory,
    GrammarChange,
    GrammarScore,
    HeliosOneWorkflowOutput,
    InitialScores,
    Issue,
    IssueCategory,
    IssueScores,
    MergingActivityOutput,
    Parameters,
    ParserResponse,
    QualityScore,
    RewriteResponse,
    Rfc9457Error,
    ScoreOutput,
    SentenceLengthActivityOutput,
    SentenceLengthCategory,
    SentenceLengthChange,
    SentenceStructureCategory,
    SentenceStructureChange,
    SentenceStructureOutput,
    SimpleVocabCategory,
    SimpleVocabChange,
    SimpleVocabOutput,
    StyleCheckResponse,
    StyleGuide,
    StyleGuideCategory,
    StyleGuideChange,
    StyleGuideOutput,
    StyleGuideResponse,
    StyleGuideScore,
    StyleGuideStatus,
    StyleGuides,
    Subcategory,
    Suggestion,
    SuggestionResponse,
    TermReplaceActivityOutput,
    TermReplaceCategory,
    TermReplaceChange,
    TerminologyScore,
    TheiaOutput,
    ToneCategory,
    ToneChange,
    ToneCheckOutput,
    ToneScore,
    Tones,
    WorkflowError,
    WorkflowResponse,
    WorkflowStatus,
    WorkflowStatusResponse,
)
from .errors import InternalServerError, NotFoundError, UnprocessableEntityError
from . import style_checks, style_guides, style_rewrites, style_suggestions
from .client import Acrolinx, AsyncAcrolinx
from .environment import AcrolinxEnvironment
from .style_checks import StyleChecksGetStyleCheckResponse
from .style_rewrites import StyleRewritesGetStyleRewriteResponse
from .style_suggestions import StyleSuggestionsGetStyleSuggestionResponse
from .version import __version__

__all__ = [
    "Acrolinx",
    "AcrolinxEnvironment",
    "AcrolinxScorerActivityOutput",
    "Analysis",
    "AsyncAcrolinx",
    "CheckOptions",
    "ClarityScore",
    "ContentQualityFeedback",
    "ContentScorerActivityOutput",
    "ContentSuggestions",
    "Dialects",
    "ErrorDetail",
    "ErrorResponse",
    "FinalScores",
    "GrammarActivityOutput",
    "GrammarCategory",
    "GrammarChange",
    "GrammarScore",
    "HeliosOneWorkflowOutput",
    "InitialScores",
    "InternalServerError",
    "Issue",
    "IssueCategory",
    "IssueScores",
    "MergingActivityOutput",
    "NotFoundError",
    "Parameters",
    "ParserResponse",
    "QualityScore",
    "RewriteResponse",
    "Rfc9457Error",
    "ScoreOutput",
    "SentenceLengthActivityOutput",
    "SentenceLengthCategory",
    "SentenceLengthChange",
    "SentenceStructureCategory",
    "SentenceStructureChange",
    "SentenceStructureOutput",
    "SimpleVocabCategory",
    "SimpleVocabChange",
    "SimpleVocabOutput",
    "StyleCheckResponse",
    "StyleChecksGetStyleCheckResponse",
    "StyleGuide",
    "StyleGuideCategory",
    "StyleGuideChange",
    "StyleGuideOutput",
    "StyleGuideResponse",
    "StyleGuideScore",
    "StyleGuideStatus",
    "StyleGuides",
    "StyleRewritesGetStyleRewriteResponse",
    "StyleSuggestionsGetStyleSuggestionResponse",
    "Subcategory",
    "Suggestion",
    "SuggestionResponse",
    "TermReplaceActivityOutput",
    "TermReplaceCategory",
    "TermReplaceChange",
    "TerminologyScore",
    "TheiaOutput",
    "ToneCategory",
    "ToneChange",
    "ToneCheckOutput",
    "ToneScore",
    "Tones",
    "UnprocessableEntityError",
    "WorkflowError",
    "WorkflowResponse",
    "WorkflowStatus",
    "WorkflowStatusResponse",
    "__version__",
    "style_checks",
    "style_guides",
    "style_rewrites",
    "style_suggestions",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .parameters import Parameters


class ParserResponse(UniversalBaseModel):
    msg_hash: typing.Optional[str] = pydantic.Field(default=None)
    """
    The hash of the messages used to run the activity
    """

    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    The error that occurred during the activity
    """

    duration: float = pydantic.Field()
    """
    The duration of the activity in seconds
    """

    model: typing.Optional[str] = pydantic.Field(default=None)
    """
    The model used to run the activity
    """

    parameters: typing.Optional[Parameters] = pydantic.Field(default=None)
    """
    The parameters used to run the activity
    """

    prompt: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    The prompt used to run the activity
    """

    completion: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    The completion used to run the activity
    """

    provider: typing.Optional[str] = pydantic.Field(default=None)
    """
    The provider used to run the activity
    """

    repair_log: typing.Optional[typing.List[typing.Dict[str, str]]] = pydantic.Field(default=None)
    """
    The LLM output's JSON repair log for the activity
    """

    run_id: str = pydantic.Field()
    """
    The Temporal workflow run ID
    """

    workflow_id: str = pydantic.Field()
    """
    The Temporal workflow ID
    """

    extracted_text: str = pydantic.Field()
    """
    The extracted text from the file.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

SentenceLengthCategory = typing.Union[
    typing.Literal["capitalization", "remove", "extract", "shorten", "deletion", "replace", "other"], typing.Any
]
